/*
 *	fhist - file history and comparison tools
 *	Copyright (C) 1998, 2002, 2004 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: functions to locate the library directory
 */

#include <../etc/libdir-h>
#include <libdir.h>


const char *
configured_libdir(void)
{
    return LIBDIR;
}


const char *
configured_datadir(void)
{
    return DATADIR;
}


const char *
configured_mandir(void)
{
    return MANDIR;
}


const char *
configured_nlsdir(void)
{
    return NLSDIR;
}
